/* migstat08_sas.zip: 03 Vorlauf 2008.sas 


SAS-PROGRAMME ZUR TYPISIERUNG DES MIGRATIONSSTATUS IM MIKROZENSUS 2008 

Programmautor/en:
SAS-Originalprogramm: Gunter Brueckner (Statistisches Bundesamt;
             Referat F 204 Migration und integration, Wohnen);
Anpassungen an Scientific Use File Mikrozensus 2008: Delia Jaeger, 
             Bernhard Schimpl-Neimanns (GESIS, GML)

Programmzweck:
   Diese Programmreihe dient der Replikation des Migrationsstatus, Variable 
   MIG, und der Staatsangehoerigkeit zum Migrationsstatus (MIGS) im 
   Scientific Use File (SUF) des Mikrozensus 2008.
   Die Programme basieren auf den SAS-Programmen zum Original-Mikrozensus 
   des Statistischen Bundesamtes und wurden an Recodierungen des SUF 
   angepasst.
   Bei der Replikation der Variablen Staatsangehoerigkeit zum Migrationsstatus
   (MIGS) ist zu beachten, dass aus Gruenden des Datenschutzes Angaben zur 
   zweiten Staatsangehoerigkeit (EF370) nur rudimentaer vorhanden sind. 
   Des Weiteren sind die zur Konstruktion von MIGS verwendeten Variablen
       EF369 1. Staatsangehoerigkeit
   und EF374 Staatsangehoerigkeit: vor Einbuergerung/Zuzug als Spaetaussiedler
   unterschiedlich codiert. Die Replikation ist deshalb nur eingeschraenkt 
   moeglich.

Weiterfuehrende Programmbeschreibung:                                
   Jaeger, Delia und Bernhard Schimpl-Neimanns: Typisierung des       
   Migrationshintergrundes in den Mikrozensus Scientific-Use-Files    
   2005-2009. GESIS-Technical Report Nr. 2012/08. Mannheim: GESIS.    
   URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
        gesis_reihen/gesis_methodenberichte/2012/TechnicalReport_2012-08.pdf

Download dieser Datei:                                               
   http://www.gesis.org/missy/studie/klassifikationen/konzepte-und-definitionen/
   migrationshintergrund/migstat08_sas.zip

Siehe auch Anhang 1: Personen mit Migrationshintergrund - Auf        
   dem Weg zu einer definitorischen Abgrenzung - S. 398-407 in:       
   Statistisches Bundesamt, 2011: Bevoelkerung mit Migrationshintergrund.
   Ergebnisse des Mikrozensus 2009. Fachserie 1 Reihe 2.2. Wiesbaden. 
   URL: https://www.destatis.de/DE/Publikationen/Thematisch/Bevoelkerung/
   MigrationIntegration/Migrationshintergrund2010220097004.pdf?__blob= 
   publicationFile; letzter Zugriff: 24.07.2012            
                                                                    
Programmstruktur:
0. Datenvorbereitung: 03 Vorlauf 2008.sas, 04 Grundtypisierung MigH 2008.sas
1. Grundtypisierung des Migationshintergrundes: 04 Grundtypisierung MigH 2008.sas
2. Identifikation von 3-Generationen-Haushalten: 05 Grosseltern-Eltern 2008.sas
3. Endtypisierung der Grosseltern: 06 Endtypisierung Grosseltern 2008.sas
4. Endtypisierung der Eltern: 07 Endtypisierung Eltern 2008.sas
5. Endtypisierung Befragte: 08 Endtypisierung Befragte 2008.sas
6. Umsetzung von Zeitreihenkompatibilitaet (nur MZ 2005 und 2009, entfaellt im MZ 2008)
7. Variablendefinition fuer SUF- und Fachserien-Ergebnisse: 08 Endtypisierung Befragte 2008.sas

Programmstatus:
  Getestet mit SAS 9.1 for Windows und dem Scientific Use File Mikrozensus 2008,
  Version 2 vom 06. 04. 2011. 
  Stand: Juli 2012.
*/


OPTIONS NOFMTERR; RUN;   /* ohne Formate */

/* Arbeitsverzeichnis in '<...>' eintragen; z. B. c:\temp */
libname mzjahr '<Arbeitsverzeichnis'>;


/* Variablenauswahl Scientific Use File MZ 2008, Version 2 
   Umbenennen der Original-Veriablen MIG => MIGS_O und MIGS => MIGS_O */
data mzjahr.mz2008_mig (KEEP=EF1 EF3   EF4   EF5a  EF5b  EF8   EF9
   EF12  EF30  EF31  EF44  EF46  EF47  EF49  EF50  EF51  EF52  EF53  
   EF54  EF55  EF366 EF367 EF368 EF369 EF370 EF371 EF372 EF373 EF374
   EF952 MIG_O MIGS_O  Version);
   retain EF1   EF3   EF4   EF5a  EF5b  EF8   EF9
   EF12  EF30  EF31  EF44  EF46  EF47  EF49  EF50  EF51  EF52  EF53  
   EF54  EF55  EF366 EF367 EF368 EF369 EF370 EF371 EF372 EF373 EF374
   EF952 MIG_O MIGS_O  Version;
   
/* Datenquelle: Scientific Use File Mikrozensus 2008, Version 2; 
   lokalen Dateinamen in < > eintragen */
set mzjahr.<mz08> (rename = (MIG=MIG_O MIGS=MIGS_O)) ;
run;


/*	0. Datenvorbereitung

	Vorlauf 
	Die Vorlaufprozedur selektiert die validen Spaetaussiedler, d.h.
	Zugewanderte mit EF372=2,4 in der Bevoelkerung am Haupt- und Nebenwohnsitz
	Gespeichert wird nur EF1-EF5, EF12 und Zuzugsjahr; die Daten dienen dem
	Ermitteln von Ehegatten/Kindern von Spaetaussiedlern, die den Status von 
	Eingebuergerten haben */


data mzjahr.vorlauf (KEEP=_EF1_ _EF3_ _EF4_ _EF5a_ _EF5b_ _EF12_ _Jahrzuzug_);
set mzjahr.mz2008_mig;
	if ef367 = 1949 then JahrZuzug=1949; /* Zuzug vor 1950 */
	else if ef367 = 9999 then JahrZuzug=9; /* o.A. zum Zuzugsjahr */
	else if ef367 = 0    then JahrZuzug=0; /* kein Zuzugsjahr sinnvoll */
	else JahrZuzug=ef367; /* Zuzug 1950-200X */
	_EF1_=EF1; _EF3_=EF3; _EF4_=EF4; _EF5a_=EF5a; _EF5b_=EF5b; _EF12_=EF12;
	_jahrzuzug_=jahrzuzug;

	if EF366 = 8 and EF372 in (2,4) and Jahrzuzug>1949 then do;
		output mzjahr.vorlauf;
	end;
run;


