/* migstat08_sas.zip: 04 Grundtypisierung MigH 2008.sas */



OPTIONS NOFMTERR; RUN;   /* ohne Formate */

/* Arbeitsverzeichnis in '<...>' eintragen; z. B. c:\temp */
libname mzjahr '<Arbeitsverzeichnis'>;



/* 1. Grundtypisierung des Migationshintergrundes 

	Es werden nur die Angaben der Person selbst zur Typsierung verwendet. */

data mzjahr.MZTypisiert (KEEP=EF1 EF3 EF4 EF5a EF5b EF12 Berichtsjahr EF30 EF46 Geschlecht EF47 
	GeburtsJahr EF49 Familienstand EF366 BRDBorn Zuzug EF367 JahrZuzug EF368 
	Auslaender EF369-EF370 SADoppelt SA1 SA2 EF372 Eingebuergert Spaetaussiedler EF373 
	JahrEinbuergerung EF374 SA3 MIG0 MIG SA SA_erw
	AHRFQ Anzahl MIG_O MIGS_O
	EF374_O);

	retain EF1 EF3 EF4 EF5a EF5b EF12 Berichtsjahr EF46 Geschlecht EF30 EF47 GeburtsJahr EF49 
	Familienstand EF366 BRDBorn Zuzug EF367 JahrZuzug EF368 Auslaender 
	EF369-EF370 SADoppelt SA1 SA2 EF372 Eingebuergert Spaetaussiedler EF373 
	JahrEinbuergerung EF374 SA3 MIG0 MIG SA SA_erw
	AHRFQ Anzahl MIG_O MIGS_o EF374_O;

* Variablenauswahl Scientific Use File MZ 2008, Version 2;
set mzjahr.mz2008_mig;
/*	Hash-Tabelle zum Ueberpruefen von moeglichen Ehegatten/Eltern Spaetaussiedler anlegen */

	if _n_=1 then do;
		_ef1_=00; _ef3_=00000; _ef4_=000; _ef5a_=00; _ef5b_=0; _ef12_=0; _jahrzuzug_=0; 
		declare hash vorlauf(dataset: "mzjahr.vorlauf");
		vorlauf.defineKey("_ef1_"); 
		vorlauf.defineKey("_ef3_"); 
		vorlauf.defineKey("_ef4_"); 
		vorlauf.defineKey("_ef5a_"); 
		vorlauf.defineKey("_ef5b_"); 
		vorlauf.defineKey("_ef12_"); 
		vorlauf.defineData("_jahrzuzug_");	
		vorlauf.defineDone();
	end;

/*	Variablenbeschreibungen siehe Datenhandbuch zum Mikrozensus Scientific Use File 2008:
	http://www.gesis.org/missy/fileadmin/missy/erhebung/datenhandbuch/DHB_2008.pdf */

/*	####### Geschlecht, Geburtsjahr und Familienstand der Person ####### */
/*	Geschlecht (EF46):
		1=maennlich; 
		2=weiblich; 
	Geburtsjahr (EF47):
		1911-2006=Jahr;
		1910=1910 oder vorher;
	Familienstand (EF49):
		1=ledig; 
		2=verheiratet; 
		3=verwitwet;
		4=geschieden; 
		5=eingetragene Lebenspartnerschaft; 
		6=eingetragener Lebenspartner verstorben;
		7=eingetragene Lebenspartnerschaft aufgehoben;
	AHRFQ: Hochrechnungsfaktor 
		=EF952
	Anzahl: Recordcount
		=1 */
	Geschlecht=ef46; 
	GeburtsJahr=ef47; 
	Familienstand=ef49; 
	Berichtsjahr=2008; 
	AHRFQ=EF952;
	Anzahl=1;

/*	####### Zuzug, Jahr des Zuzugs ####### */
/*	BRDBorn (EF366): 
		1=hier geboren; 
		8=zugezogen; 
		9 oder ' ' =k.A. 
	Zuzug:   
		0=kein Zuzug; 
		1=foreign born; 
		2=Zuzug nach mehr als 6 Monaten im Ausland, d.h. in Deutschland geboren;
		9=k.A. 
	JahrZuzug (EF367):   
		1949=1949 und frueher; 
		1950-2006= jeweiliges Jahr; 
		9=k.A. */
	BRDBorn=ef366; 
	if BRDBorn=1 then Zuzug=0; 
	else if BRDBorn=8 then Zuzug=1; 
	else if BRDBorn=9 then Zuzug=9; 
	else Zuzug=9; 

	if ef367 = 1949 then JahrZuzug=1949; /* Zuzug vor 1950 */
	else if ef367 = 9999 then JahrZuzug=9; /* o.A. zum Zuzugsjahr */
	else if ef367 = 0    then JahrZuzug=0; /* kein Zuzugsjahr sinnvoll */
	else JahrZuzug=ef367; /* Zuzug 1950-200X */

	if (BRDBorn=1 and Jahrzuzug>9) then Zuzug=2;
	if (BRDBorn=8 and Jahrzuzug<10) then Jahrzuzug=9;


/*	####### Nationalitaet und Staatsangehoerigkeit ####### */


/* 0. Datenvorbereitung
      Harmonisierung Staatsangehoerigkeit: Anpassung von EF374 an EF369 und MIGS */
EF374_O = EF374; /* Originalfassung sichern  */
if (EF374 = 3)  then EF374=25;  /* 25 = 3/25: Bulgarien(3); Rumaenien(25) */
if (EF374 = 8)  then EF374=4;   /*  4 = 4/8/27: Daenemark(4); Finnland(8); Schweden(27) */
if (EF374 = 1)  then EF374=21;  /* 21 = 1/18/21: Belgien(1); Luxemburg(18); Niederlande(21) */
if EF374 in (7,15,17) then EF374=31; /* 7/15/17/19/31/37: Estland(7); Lettland(15); Litauen(17); Malta(19); Slowenien(31); Zypern(37) */
if (EF374 = 30) then EF374=33;  /* 33 = 30/33: Slowakei(30); Tschechische Republik(33) */
if (EF374 = 98) then EF374=55;  /* 55 = 55/98: Uebrige Welt(55); Staatenlos(98) */
/* Zu beachten: 
EF370 2. Staatsangehoerigkeit
      0 Auslaender mit nur einer Staatsangehoerigkeit
      1 Nur deutsche Staatsangehoerigkeit / Deutsche und weitere Staatsangehoerigkeit
Die einzelnen Staatsangehoerigkeiten sind nicht ausgewiesen.
Um Fehlinterpretationen durch die Zuweisung "SA2=ef370" zu vermeiden, wird diese unten deaktiviert. */


/* 1. Grundtypisierung des Migationshintergrundes */
/*	Auslaender (EF368-EF370):
		0=deutsche Staatsangehoerigkeit (einschliesslich doppelte); 
		1=nicht-deutsche Staatsangehoerigkeit;
	SADoppelt: doppelte Staatsangehoerigkeit (EF368-EF370)
		0=keine doppelte Staatsangehoerigkeit;
		1=doppelte Staatsangehoerigkeit;
	SA1: Aktuelle (erste) Staatsangehoerigkeit (EF368-EF370)
		0=deutsch;
		1-55,98=jeweilige auslaendische Staatsangehoerigkeit;
	SA2: Aktuelle (zweite) Staatsangehoerigkeit (EF368-EF370)
		.=unzutreffend;
		1-59,98=jeweilige auslaendische Staatsangehoerigkeit; */

	if ef368=1 then do; /* nur deutsche SA */
		Auslaender=0; SADoppelt=0; SA1=0; SA2=.;
	end;
	else if ef368=2 then do; /* deutsche und auslaendische SA */
		Auslaender=0; SADoppelt=1; SA1=0; SA2=ef369;
	end;
	else do; /* nur auslaendische SAs */
		Auslaender=1; SA1=ef369;
		if ef370=0 then do;
			SADoppelt=0; SA2=.;
		end;
		else do;
			SADoppelt=1; /* SA2=ef370; --- Deaktiviert --- */
		end;
	end;

/*	####### Eingebuergerte/Spaetaussiedler und Staatsangehoerigkeit davor ####### */
/*	"Erwerb der dt. Staatsangehoerigkeit": (EF372 neue Codes ab 2007):
		Deutsche Staatsangehoerigkeit durch Geburt: 
				Spaetaussiedler=9; Eingebuergert=0;
		Deutsche Staatsangehoerigkeit als Spaetaussiedler mit Einbuergerung: 
				Spaetaussiedler=1; Eingebuergert=1;
		Deutsche Staatsangehoerigkeit als Spaetaussiedler ohne Einbuergerung: 
				Spaetaussiedler=1; Eingebuergert=0;
		Deutsche Staatsangehoerigkeit durch Einbuergerung: 
				Spaetaussiedler=0; Eingebuergert=1;
	JahrEinbuergerung (EF373):
		1910-2006= jeweiliges Jahr; 
		9=k.A. 
	SA3: Staatsangehoerigkeit vor Einbuergerung/Zuzug als Spaetaussiedler (EF374)
		.=k.A.;
		0=deutsch bzw. unzutreffend;
		1-59,98=jeweilige auslaendische Staatsangehoerigkeit; */

	if ef372=2 then do; 
	/* Spaetaussiedler mit Einbuergerung  */
		Spaetaussiedler=1; Eingebuergert=1;
		if ef373 = 0 then JahrEinbuergerung=9; /* Einbuergerungsjahr */
			else JahrEinbuergerung=ef373; 
		if ef374 = 0 then SA3=.; else SA3=ef374; /* SA vor Einbuergerung */
		if ef369 = 0 then SA2=.; else SA2=ef369; /* 2. SA */
	end;
	else if ef372=4 then do; /* Spaetaussiedler ohne Einbuergerung */
		Spaetaussiedler=1; Eingebuergert=0; JahrEinbuergerung=.; 
		if ef374 = 0 then SA3=.; else SA3=ef374; /* SA vor Zuzug */
		if ef369 = 0 then SA2=.; else SA2=ef369; /* 2. SA */
	end;
	else if ef372=3 then do; /* sonstige Einbuergerung */
		Spaetaussiedler=0; Eingebuergert=1; 
		if ef373 = 0 then JahrEinbuergerung=9; /* Einbuergerungsjahr */
			else JahrEinbuergerung=ef373; 
		if ef374 = 0 then SA3=.; else SA3=ef374; /* SA vor Einbuergerung */
		if ef369 = 0 then SA2=.; else SA2=ef369; /* 2. SA */
	end;
	else do; /* Deutsch durch Geburt */
		Spaetaussiedler=0; Eingebuergert=0; JahrEinbuergerung=.; SA3=0;
		if ef369 = 0 then SA2=.; else SA2=ef369; /* 2. SA */
	end;

/*	####### Grundtypisierung des Migrationshintergrundes ####### */
/*	MIG: Migrationstypus
	1. Stelle: 	Migrationstyp: 
		1=vertrieben;
		2=als Deutsche/r bzw. Spaetaussiedler zugewandert;
		3=eingebuergert;
		4=Auslaender/in;
	2. Stelle:	Generation: 
		1=im Ausland geboren, 
		2=in Deutschland geboren 

	MIG:
		11=Vertriebene vor 1950;
		21=Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne Einbuergerung);
		22=Ehegatte oder Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuergerung);
		25=(Spaet-)Aussiedler (mit Einbuergerung);
		29=(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr;
		31=zugewanderte/r eingebuergerte/r Auslaender/in;
		32=nicht zugewanderte/r eingebuergerte/r Auslaender/in;
		41=zugewanderte/r Auslaender/in;
		42=nicht zugewanderte/r Auslaender/in;
		77=uneindeutig ob deutsch, vertrieben oder Spaetaussiedler 
		99=fehlende/unvollstaendige Angaben 
	SA: aktuelle Staatsangehoerigkeit

	SA_erw: erweiterte aktuelle Staatsangehoerigkeit
		gewonnen aus SA1 - SA3 nach folgenden Regeln:
		0=deutsch (bei MIG=0, 11);
		=SA1 (bei Mig=41,42);
		=SA3 (bei Mig=21,25,29,31,32 und SA3<>.);
		=SA2 (bei MIG=21,25,29,31,32 und SA3=.und SA2<>.)
		=99 (bei MIG=21,25,29,31,32 und SA2=. und SA3=. oder bei MIG=77,99)	*/

	if BRDBorn=8 then do; 						 /* A) im Ausland geboren */
		if Auslaender=1 then do; 				 /* A1) als Auslaender zugewandert */
			MIG=41; SA=SA1; SA_erw=SA1; 		 /* SA und SA_erw: auslaendische SA */
		end;
		else do;								 /* ... als Deutscher zugewandert */
			if Spaetaussiedler=1 then do; 		 /* A2) Spaetaussiedler/in,  */
				if Eingebuergert=1 then do       /* Spaetaussiedler mit Einbuergerung */
					MIG=25; SA=SA1; SA_erw=SA3;  /* SA_erw: SA vor Einbuergerung, */
					if SA_erw=. then SA_erw=SA2; /* wenn fehlt, 2. SA (Doppelstaatler) */
					if SA_erw=. then SA_erw=99;  /* ansonsten 'missing' */
				end;
				else do;						 /* Spaetaussiedler ohne Einbuergerung */
					MIG=21; SA=SA1; SA_erw=SA3;  /* SA_erw: SA vor Einbuergerung, */
					if SA_erw=. then SA_erw=SA2; /* wenn fehlt, 2. SA (Doppelstaatler) */
					if SA_erw=. then SA_erw=99;  /* ansonsten 'missing' */
				end;
			end;
			else do; 						 	 /* kein Spaetaussiedler ... */
				if Eingebuergert=1 then do; 	 /* A3) Eingebuergerte/r */
					MIG=31; SA=SA1; SA_erw=SA3;  /* SA_erw: SA vor Einbuergerung, */
					if SA_erw=. then SA_erw=SA2; /* wenn fehlt, 2. SA */
					if SA_erw=. then SA_erw=99;  /* ansonsten 'missing' */
				end;
				else do; 						 /* ... Deutsche/r durch Geburt */
					if Jahrzuzug=1949 then do;   /* A4) Vertriebener vor 1950 */
						MIG=11; SA=SA1; SA_erw=SA1; /* SA_erw: SA1 */
					end;
					else if Jahrzuzug>1949 then do; /* A5) Aussiedler-Aequivalent */
						MIG=21; SA=SA1; SA_erw=SA3;  /* SA_erw: SA vor Einbuergerung, */
						if SA_erw=. then SA_erw=SA2; /* wenn fehlt, 2. SA (Doppelstaatler) */
						if SA_erw=. then SA_erw=99;  /* ansonsten 'missing' */
					end;
					else do;						 /* ... Zuzugsjahr missing */
		/*			Zuzug ohne Angabe zum Jahr d.h. kann Vertriebener oder Spaetaussiedler sein 
					Annahme 1: wenn nach 1949 geboren, als Spaetaussiedler zugewandert;
					Annahme 2: Wenn vor 1949 geboren und keine auslaendische SA dann Vertriebener; 
					Annahme 3: sonst Zuzug als Spaetaussiedler ohne Datumsangabe: 29 */

					/* Annahme 1: */
						if GeburtsJahr>1949 then do; 
							MIG=21; SA=SA1; SA_erw=SA3;  /* SA_erw: SA vor Einbuergerung, */
							if SA_erw=. then SA_erw=SA2; /* wenn fehlt, 2. SA (Doppelstaatler) */
							if SA_erw=. then SA_erw=99;  /* ansonsten 'missing' */
						end;
					/* Annahme 2: */
						else if (SADoppelt=0 and SA1=0) then do; 
							MIG=11; SA=SA1; SA_erw=SA1; 
						end;
					/* Annahme 3: */
						else do; 
							MIG=29; SA=SA1; SA_erw=SA3; /* SA_erw: 2. SA, ggf. 'missing' */
							if SA_erw=. then SA_erw=SA2; /* wenn fehlt, 2. SA (Doppelstaatler) */
							if SA_erw=. then SA_erw=99; 
						end;
					end;						        /* ... Zuzugsjahr missing */
				end; 						            /* ... Deutsche/r durch Geburt */
			end; 						 	            /* kein Spaetaussiedler ... */
		end;											/* ... als Deutscher zugewandert */
	end;		 						 				/* A) im Ausland geboren */

	else if BRDBorn=1 then do;							/* B) im Inland geboren:  */
		if Auslaender=1 then do; 				 		/* b1) als Auslaender in D geboren */
			MIG=42; SA=SA1; SA_erw=SA1; 		 		/* SA und SA_erw: auslaendische SA */
		end;
		else if Spaetaussiedler=1 then do; 		 		/* B2) Spaetaussiedler/in, Fehler! */
			MIG=77; SA=SA1; SA_erw=SA3;  				/* SA_erw: SA vor Einbuergerung, */
			if SA_erw=. then SA_erw=SA2; 				/* wenn fehlt, 2. SA (Doppelstaatler) */
			if SA_erw=. then SA_erw=99;  				/* ansonsten 'missing' */
		end;
		else if Eingebuergert=1 then do; 	 			/* B3) Eingebuergerte/r */
			/* if (EF5b=0) then MIG=32;	Jahresbestand  --- Unterschied Jahresbestand/-ueberhang im SUF --- 
			   if (ef5b=1) then MIG=31;	Jahresueberhang --- aufgehoben (Juli 2012) --- */
			MIG=32;
				SA=SA1; SA_erw=SA3;						/* SA_erw: SA vor Einbuergerung, */
			if SA_erw=. then SA_erw=SA2; 				/* wenn fehlt, 2. SA */
			if SA_erw=. then SA_erw=99;  				/* ansonsten 'missing' */
		end;
		else do; 										/* B4) in Deutschland geborener Deutscher */
			Mig=77; SA=SA1; SA_erw=SA2; 
			if SA_erw=. then SA_erw=SA1; 
		end;
	end;
	else if BRDBorn=9 then do; /* keine Auskunft; kommt wohl nicht vor */
		Mig=99; SA=SA1; SA_erw=SA3;
		if SA_erw=. then SA_erw=SA1;
	end;

/*	Wenn Zuwanderer angibt, eingebuergert zu sein (Mig=31), dann pruefen, ob ggf. 
	Spaetaussiedlerstatus vorliegt:
	a) Ehegatte ist Spaetaussiedler (MIG[Ehegatte]=21-29)
	b) Vater ist Spaetaussiedler (MIG[Vater]=21-29)
	c) Mutter ist Spaetaussiedler (MIG[Mutter]=21-29) */

	mig0 = mig; /* Migrationsstatus vor Plausibilisierung MIG=31 */

	if mig=31 then do;

/*	In Vorlauftabelle nach Ehegatte suchen */

		_ef1_=ef1; _ef3_=ef3; _ef4_=ef4; _ef5a_=ef51; _ef5b_=ef5b; _ef12_=ef12;

		_ec2_=vorlauf.find(key:_ef1_, Key:_ef3_, Key:_ef4_, Key:_ef5a_, Key:_ef5b_, Key:_ef12_);
		if not _ec2_ then do; /* wenn gefunden... 
		und valides Zuzugsjahr und +- 3 Jahre vom Zuzugsjahr des Ehegatten... */
			if jahrzuzug > 10 and abs(jahrzuzug-_jahrzuzug_)<3 then MIG=22; 
		end;
/*	wenn FA, dann in Vorlauftabelle nach Vater suchen */
		else do;
			_ef1_=ef1; _ef3_=ef3; _ef4_=ef4; _ef5a_=ef55; _ef5b_=ef5b; _ef12_=ef12;

			_ec2_=vorlauf.find(key:_ef1_, Key:_ef3_, Key:_ef4_, Key:_ef5a_, Key:_ef5b_, Key:_ef12_);
			if not _ec2_ then do; /* wenn gefunden... */
				if jahrzuzug > 10 and abs(jahrzuzug-_jahrzuzug_)<3 then MIG=22; 
			end;
/*	wenn FA, dann in Vorlauftabelle nach Mutter suchen */
			else do;
				_ef1_=ef1; _ef3_=ef3; _ef4_=ef4; _ef5a_=ef53; _ef5b_=ef5b; _ef12_=ef12;

				_ec2_=vorlauf.find(key:_ef1_, Key:_ef3_, Key:_ef4_, Key:_ef5a_, Key:_ef5b_, Key:_ef12_);

				if not _ec2_ then do; /* wenn gefunden... */
					if jahrzuzug > 10 and abs(jahrzuzug-_jahrzuzug_)<3 then MIG=22; 
				end;
			end;
		end;
	end;

run;


