/* migstat08_sas.zip: 05 Grosseltern-Eltern 2008.sas */

OPTIONS NOFMTERR; RUN;   /* ohne Formate */

/* Arbeitsverzeichnis in '<...>' eintragen; z. B. c:\temp */
libname mzjahr '<Arbeitsverzeichnis'>;


/*	2. Identifikation von 3-Generationen-Haushalten */

/*	Eltern im Haushalt isolieren, (Vater ueber EF54/EF55, Mutter EF52/EF53) und 
	Kind-Elternbezug in Tabelle eintragen */
data mzjahr.KindEltern (Keep=EF1 EF3 EF4 EF5a EF5b EF12 Typ PNr);

/*	Reihenfolge der Variablen festlegen */
	retain EF1 EF3 EF4 EF5a EF5b EF12 Typ PNr;

/*	Quelle: Variablenauswahl Scientific Use File MZ 2008, Version 2;*/
	set mzjahr.mz2008_mig;

/*	Vater im Haushalt? Wenn ja, Ausgabe mit Typ=1 und PNr=EF55 */
	if EF54 =1 then do;
		Typ=1; PNr=EF55; output mzjahr.KindEltern; 
	end;

/*	Mutter im Haushalt? Wenn ja, Ausgabe mit Typ=2 und PNr=EF53 */
	if EF52 =1 then do;
		Typ=2; PNr=EF53; output mzjahr.KindEltern;
	end;
run;

/*	Elterndatei erstellen durch Loeschen doppelter Eintraege in der Datei KindEltern, 
	die als Folge von mehr als einem Kind in der Familie auftreten */
proc sql;
create table mzjahr.Eltern as
	select distinct a.ef1, a.ef3, a.ef4, a.ef5a, a.ef5b, a.ef12, a.ef52,
		a.ef53, a.ef54, a.ef55
	from mzjahr.mz2008_mig as a, mzjahr.KindEltern as b
	where a.ef1=b.ef1 and a.ef3=b.ef3 and a.ef4=b.ef4 
		and a.ef12=b.ef12 and a.ef5a=b.PNr and a.EF5b=b.ef5b
	order by a.ef1, a.ef3, a.ef4, a.ef5a, ef5b, a.ef12;
quit;

/*	Grosseltern im Haushalt isolieren (Vater ueber EF54/EF55, Mutter EF52/EF53) und 
	Eltern-Grosselternbezug in Tabelle eintragen.
	Ausgangsmaterial ist die Elterndatei */
data mzjahr.ElternGrosseltern (Keep=EF1 EF3 EF4 EF5a EF5b EF12 Typ PNr);

/*	Reihenfolge der Variablen festlegen */
    retain EF1 EF3 EF4 EF5a EF5b EF12 Typ PNr;

/*	Quelle: Variablenauszug MZ 2008 SUF */
    set mzjahr.Eltern;

/*	Grossvater im Haushalt? Wenn ja, Ausgabe mit Typ=1 und PNr=EF55 */
    if EF54 =1 then do;
        typ=1; PNr=EF55; output mzjahr.ElternGrosseltern;
    end;

/*	Grossmutter im Haushalt? Wenn ja, Ausgabe mit Typ=2 und PNr=EF53 */
    if EF52 =1 then do;
        typ=2; PNr=EF53; output mzjahr.ElternGrosseltern;
    end;
run;

/*	Grosselterndatei erstellen durch Loeschen doppelter Eintraege in der Datei
	Grosseltern, die als Folge von mehr einem Kind der Grosseltern auftreten */
proc sql;
create table mzjahr.GrossEltern as
	select distinct a.ef1, a.ef3, a.ef4, a.ef5a, a.ef5b, a.ef12, a.ef52,
		a.ef53, a.ef54, a.ef55
	from mzjahr.mz2008_mig as a, mzjahr.ElternGrosseltern as b
	where a.ef1=b.ef1 and a.ef3=b.ef3 and a.ef4=b.ef4 
		and a.ef12=b.ef12 and a.ef5a=b.PNr and a.EF5b=b.ef5b
	order by a.ef1, a.ef3, a.ef4, a.ef5a, a.ef12;
quit;

run;
