/* migstat08_sas.zip: 07 Endtypisierung Eltern 2008.sas */

OPTIONS NOFMTERR; RUN;   /* ohne Formate */

/* Arbeitsverzeichnis in '<...>' eintragen; z. B. c:\temp */
libname mzjahr '<Arbeitsverzeichnis'>;



/*	4. Endtypisierung der Eltern */
/*	Endtypisierung des Migrationshintergrundes der Eltern */
/*	Anlegen des Ausgangsmaterials fuer Eltern */

/*	Auswahl des grundtypisierten Materials fuer alle als Eltern identifizierten Personen */
proc sql;
	create table mzjahr.elterntmp1 as
	select a.*
	from mzjahr.MZTypisiert as a, mzjahr.Eltern as b
	where  a.ef1=b.ef1 and a.ef3=b.ef3 and a.ef4=b.ef4 
		and a.ef12=b.ef12 and a.ef5a=b.ef5a and a.ef5b=b.ef5b;
quit;

/*	Aus der Datei ElternGrosseltern Bezugsnummer des Grossvaters als PNrV anmergen, ggf. missing */
proc sql;
	create table mzjahr.elterntmp2 as
	select a.*, b.PNr as PNrV
	from mzjahr.elterntmp1 as a
	left join mzjahr.ElternGrosseltern as b 
	on a.ef1=b.ef1 and a.ef3=b.ef3 and a.ef4=b.ef4 
		and a.ef12=b.ef12 and a.ef5a=b.ef5a and a.ef5b=b.ef5b and b.Typ=1;
quit;

/*	Aus der Datei ElternGrosseltern Bezugsnummer der Grossmutter als PNrM anmergen, ggf. missing */
proc sql;
	create table mzjahr.elterntmp3 as
	select a.*, b.PNr as PNrM
	from mzjahr.elterntmp2 as a
	left join mzjahr.ElternGrosseltern as b 
	on a.ef1=b.ef1 and a.ef3=b.ef3 and a.ef4=b.ef4 
		and a.ef12=b.ef12 and a.ef5a=b.ef5a and a.ef5b=b.ef5b and b.Typ=2;
quit;

/*	Migrationsrelevante Eintraege fuer Grossvaeter ueber PNrV anmergen 
	mit dem Suffix I zur ggf. erforderlichen Unterscheidung der Angaben
	zu Eltern ausserhalbs des Haushalts */
proc sql;
	create table mzjahr.elterntmp4 as
	select a.*, b.MIG as MIGVI, b.SA1 as SA1VI, b.SA2 as SA2VI, b.SA3 as SA3VI, 
		b.SA as SAVI, b.SA_erw as SA_erwVI
	from mzjahr.elterntmp3 as a 
	left join mzjahr.GrossElternTypisiert as b
	on a.ef1=b.ef1 and a.ef3=b.ef3 and a.ef4=b.ef4 
		and a.PNrV=b.ef5a and a.ef5b=b.ef5b and a.ef12=b.ef12;
quit;

/*	Migrationsrelevante Eintraege fuer Grossmuetter analog anmergen */
proc sql;
	create table mzjahr.ElternTypTmp as
	select a.*, b.MIG as MIGMI, b.SA1 as SA1MI, b.SA2 as SA2MI, b.SA3 as SA3MI, 
		b.SA as SAMI, b.SA_erw as SA_erwMI
	from mzjahr.elterntmp4 as a
	left join mzjahr.GrossElternTypisiert as b
	on a.ef1=b.ef1 and a.ef3=b.ef3 and a.ef4=b.ef4 
		and a.PNrM=b.ef5a and a.ef5b=b.ef5b and a.ef12=b.ef12;
quit;

/*	Typisierung der Eltern unter Einbeziehung ggf. vorhandener Angaben zum
	Migrationsstatus der Grosseltern 
	Es liegen ausserdem Angaben zu Migrationsstatus der nicht im Haushalt lebenden 
	Grosseltern vor, die beruecksichtigt werden muessten */
data mzjahr.ElternTypisiert (KEEP=EF1 EF3 EF4 EF5a EF5b EF12 Berichtsjahr Geschlecht 
	Jahrzuzug MIG SA1 SA2 SA3 SA SA_erw MIGV SAV SA_erwV MIGM SAM SA_erwM)

	ErrorEltern0 (Keep=EF1 EF3 EF4 EF5a EF5b EF12 p v m kennung);

	retain EF1 EF3 EF4 EF5a EF5b EF12 Berichtsjahr Geschlecht 
	Jahrzuzug MIG SA1 SA2 SA3 SA SA_erw MIGV SAV SA_erwV MIGM SAM SA_erwM;
 
/*	Quelle ist die Datei 'GrosselternTypTmp' */
	set mzjahr.ElternTypTmp; 

/*	------------------------------------------------------------------------ */
/*	'Converse' enthaelt die Abbildungsvorschriften zur Ermittlung des
	Migrationsstatus aus den Werten MIG, MIGV und MIGM.
	Fuer jede Kombination von eigenem, vaeterlichen und muetterlichen 
	vorlaeufigen Migrationsstatus wird der resultierende endgueltige
	Migrationsstatus zurueckgegeben. Die Variable Kennung enthaelt den 
	Fallidentifikator, der die Abbildungsvorschrift eindeutig identifiziert 
	Version converse: ex conversion_2011.xls (05.07.2012) */

/*	Vorbelegen der Werte und Definieren der Hash-Table */
	if _n_=1 then do;
		_mig_=0; _migv_=0; _migm_=0; migneu=0; Kennung=0;
		declare hash converse(dataset: "mzjahr.converse");
		converse.defineKey("_mig_"); 
		converse.defineKey("_migv_"); 
		converse.defineKey("_migm_"); 
		converse.defineData("migneu");	
		converse.defineData("kennung");	
		converse.defineDone();
	end;

* (...) ;
/*	--------------------------------------------------------------------------- */
/*	Hier folgt der Code zur Umsetzung der internen Angaben zum
	Migrationsstatus der Eltern fuer die Jahre 2006-2008 und 2010-2012 */

/*	Die Variablen xxxV werden durch die entspechenden Werte von xxxVI bestimmt. 
	Vorgehensweise bei xxxM entsprechend */

	MIGV=MIGVI; SA1V=SA1VI; SA2V=SA2VI; SA3V=SA3VI; SAV=SAVI; SA_erwV=SA_erwVI;
/*	Wenn die Angaben fehlen ... */
	if MIGVI=. then do;
		MIGV=99; SA1V=99; SA2V=99; SA3V=99; SAV=99; SA_erwV=99;
	end;

	MIGM=MIGMI; SA1M=SA1MI; SA2M=SA2MI; SA3M=SA3MI; SAM=SAMI; SA_erwM=SA_erwMI;
/*	Wenn die Angaben fehlen ... */
	if MIGMI=. then do;
		MIGM=99; SA1M=99; SA2M=99; SA3M=99; SAM=99; SA_erwM=99;
	end;

/*	------------------------------------------------------------------------ */
/*	nur im Inland Geborene werden der Konversions-Prozedur unterworfen */
if not (MIG in (11, 21, 22, 23, 25, 29, 31, 41)) then do; 

/*	durch Konversion koennen fuer Vater und Mutter neue Mig-Werte entstanden sein,
	fuer die die Konversionstabelle keine Abbildungvorschrift enthaelt. Fuer diese Werte
	werden kompatible, in der Konversionstabelle definierte Ersatzwerte eingestellt */
	p=MIG;
	v=MIGV; If MIGV=0 then v=99; if MIGV in (22,23) then v=21;
	m=MIGM; If MIGM=0 then m=99; if MIGM in (22,23) then m=21;

/*	In Konversiontabelle Abbildung fuer Mig-Werte nachschlagen */
	_ec2_=converse.find(key:p, Key:v, Key:m);
	if _ec2_ then do; /* wenn nicht gefunden... */
/*	in Fehlerdatei die nicht-definierte Kombination von Mig, MigV, MigM ausgeben */
		output ErrorEltern0;
	end; 
	else do; /* wenn gefunden (hoffentlich)... */
		MIG=migneu; 
	end;

/*	SA_erw durch aussagekraeftigen Vatereintrag ergaenzen, sofern noetig und moeglich */
	if ((SA_erw in (0,99)) and (SA_erwV not in (0,99))) then SA_erw=SA_erwV;

/*	SA_erw durch aussagekraeftigen Muttereintrag ergaenzen, sofern noch immer noetig 
	und moeglich */
	if ((SA_erw in (0,99)) and (SA_erwM not in (0,99))) then SA_erw=SA_erwM;
end;

/*	im Ausland geborene Migranten direkt ausgegeben */
else do; 
	if MIG=11 then Kennung=1;
	else if MIG=21 then Kennung=2;
	else if MIG=22 then Kennung=2;
	else if MIG=23 then Kennung=3;
	else if MIG=25 then Kennung=3;
	else if MIG=29 then Kennung=4;
	else if MIG=31 then Kennung=5;
	else if MIG=41 then Kennung=6;
end;


output mzjahr.ElternTypisiert;
run;

