/* migstat08_sas.zip:  08 Endtypisierung Befragte 2008.sas */

OPTIONS NOFMTERR; RUN;   /* ohne Formate */

/* Arbeitsverzeichnis in '<...>' eintragen; z. B. c:\temp */
libname mzjahr '<Arbeitsverzeichnis'>;



/*	5. Endtypisierung Befragte */

/*	Endtypisierung des Migrationshintergrundes der Befragten */
/*	Anlegen des Ausgangsmaterials fuer Befragte */

/*  Auswahl des grundtypisierten Materials fuer alle Befragten 
	entspricht der Datei mzjahr.MZTypisiert */


/*	Aus der Datei KindEltern Bezugsnummer des Vaters als PNrV anmergen, ggf. missing */
proc sql;
	create table mzjahr.befragtetmp2 as
	select a.*, b.PNr as PNrV
	from mzjahr.MZTypisiert as a
	left join mzjahr.KindEltern as b 
	on a.ef1=b.ef1 and a.ef3=b.ef3 and a.ef4=b.ef4 
		and a.ef12=b.ef12 and a.ef5a=b.ef5a and a.ef5b=b.ef5b and b.Typ=1;
quit;

/*	Aus der Datei KindEltern Bezugsnummer der Mutter als PNrM anmergen, ggf. missing */
proc sql;
	create table mzjahr.befragtetmp3 as
	select a.*, b.PNr as PNrM
	from mzjahr.befragtetmp2 as a
	left join mzjahr.KindEltern as b 
	on a.ef1=b.ef1 and a.ef3=b.ef3 and a.ef4=b.ef4 
		and a.ef12=b.ef12 and a.ef5a=b.ef5a and a.ef5b=b.ef5b and b.Typ=2;
quit;

/*	Migrationsrelevante Eintraege fuer Vaeter ueber PNrV anmergen */
proc sql;
	create table mzjahr.befragtetmp4 as
	select a.*, b.Jahrzuzug as JahrzuzugVI, b.MIG as MIGVI, b.SA1 as SA1VI, 
		b.SA2 as SA2VI, b.SA3 as SA3VI, b.SA as SAVI, b.SA_erw as SA_erwVI 
	from mzjahr.befragtetmp3 as a 
	left join mzjahr.ElternTypisiert as b
	on a.ef1=b.ef1 and a.ef3=b.ef3 and a.ef4=b.ef4 
		and a.PNrV=b.ef5a and a.ef5b=b.ef5b and a.ef12=b.ef12;
quit;

/*	Migrationsrelevante Eintraege fuer Muetter anmergen */
proc sql;
	create table mzjahr.BefragteTypTmp as
	select a.*, b.MIG as MIGMI, b.Jahrzuzug as JahrzuzugMI, b.SA1 as SA1MI, 
		b.SA2 as SA2MI, b.SA3 as SA3MI, b.SA as SAMI, b.SA_erw as SA_erwMI
	from mzjahr.befragtetmp4 as a
	left join mzjahr.ElternTypisiert as b
	on a.ef1=b.ef1 and a.ef3=b.ef3 and a.ef4=b.ef4 
		and a.PNrM=b.ef5a and a.ef5b=b.ef5b and a.ef12=b.ef12;
quit;

/*	Typisierung der Befragten unter Einbeziehung ggf. vorhandener Angaben zum
	Migrationsstatus der Eltern
	Es liegen ausserdem Angaben zu Migrationsstatus der nicht im Haushalt lebenden 
	Eltern vor, die beruecksichtigt werden muessten */
data mzjahr.BefragteTypisiert (KEEP=EF1 EF3 EF4 EF5a EF5b EF12 EF30 Berichtsjahr Geschlecht 
	Zuzug Jahrzuzug JahrzuzugV JahrzuzugM MIG MIGS MIGS_R SA1 SA2 SA3 SA SA_erw MIGV SAV SA_erwV MIGM SAM SA_erwM
	AHRFQ Anzahl MIG_O MIGS_O EF374_O)

	ErrorBefragte (Keep=EF1 EF3 EF4 EF5a EF5b EF12 p v m kennung);

	retain EF1 EF3 EF4 EF5a EF5b EF12 EF30 Berichtsjahr Geschlecht Zuzug 
	Jahrzuzug JahrzuzugV JahrzuzugM MIG MIGS MIGS_R SA1 SA2 SA3 SA SA_erw MIGV SAV SA_erwV MIGM SAM SA_erwM
	AHRFQ Anzahl MIG_O MIGS_O EF374_O;
 
/*	Quelle ist die Datei 'BefragteTypTmp' */
	set mzjahr.BefragteTypTmp; 

/*	------------------------------------------------------------------------ */
/*	'Converse' enthaelt die Abbildungsvorschriften zur Ermittlung des
	Migrationsstatus aus den Werten MIG, MIGV und MIGM.
	Fuer jede Kombination von eigenem, vaeterlichen und muetterlichen 
	vorlaeufigen Migrationsstatus wird der resultierende endgueltige
	Migrationsstatus zurueckgegeben. Die Variable Kennung enthaelt den 
	Fallidentifikator, der die Abbildungsvorschrift eindeutig identifiziert 
    Version converse: ex conversion_2011.xls (05.07.2012) */

/*	Vorbelegen der Werte und Definieren der Hash-Table */
	if _n_=1 then do;
		_mig_=0; _migv_=0; _migm_=0; migneu=0; Kennung=0;
		declare hash converse(dataset: "mzjahr.converse");
		converse.defineKey("_mig_"); 
		converse.defineKey("_migv_"); 
		converse.defineKey("_migm_"); 
		converse.defineData("migneu");	
		converse.defineData("kennung");	
		converse.defineDone();
	end;

* (...);
/*	--------------------------------------------------------------------------- */
/*	Hier folgt der Code zur Umsetzung der internen Angaben zum
	Migrationsstatus der Eltern fuer die Jahre 2006-2008 und 2010-2012 */

/*	Die Variablen xxxV werden durch die entspechenden Werte von xxxVI bestimmt. 
	Vorgehensweise bei xxxM entsprechend */

	MIGV=MIGVI; SA1V=SA1VI; SA2V=SA2VI; SA3V=SA3VI; SAV=SAVI; SA_erwV=SA_erwVI;
	JahrzuzugV=JahrzuzugVI; 
/*	Wenn die Angaben fehlen ... */
	if MIGVI=. then do;
		MIGV=99; SA1V=99; SA2V=99; SA3V=99; SAV=99; SA_erwV=99; JahrzuzugV=9; 
	end;

	MIGM=MIGMI; SA1M=SA1MI; SA2M=SA2MI; SA3M=SA3MI; SAM=SAMI; SA_erwM=SA_erwMI;
	JahrzuzugM=JahrzuzugMI; 
	/*	Wenn die Angaben fehlen ... */
	if MIGMI=. then do;
		MIGM=99; SA1M=99; SA2M=99; SA3M=99; SAM=99; SA_erwM=99; JahrzuzugM=9;
	end;

* (...);
/*	------------------------------------------------------------------------ */
/*	nur im Inland Geborene werden der Konversions-Prozedur unterworfen */
if not (MIG in (11, 21, 22, 23, 25, 29, 31, 41)) then do; 

/*	durch Konversion koennen fuer Vater und Mutter neue Mig-Werte entstanden sein,
	fuer die die Konversionstabelle keine Abbildungvorschrift enthaelt. Fuer diese Werte
	werden kompatible, in der Konversionstabelle definierte Ersatzwerte eingestellt */
	p=MIG;
	v=MIGV; If MIGV=0 then v=99; if MIGV in (22,23) then v=21;
	m=MIGM; If MIGM=0 then m=99; if MIGM in (22,23) then m=21;

/*	In Konversiontabelle Abbildung fuer Mig-Werte nachschlagen */
	_ec2_=converse.find(key:p, Key:v, Key:m);
	if _ec2_ then do; /* wenn nicht gefunden... */
/*	in Fehlerdatei die nicht-definierte Kombination von Mig, MigV, MigM ausgeben */
		output ErrorBefragte;
	end; 
	else do; /* wenn gefunden (hoffentlich)... */
		MIG=migneu; 
	end;

/*	SA_erw durch aussagekraeftigen Vatereintrag ergaenzen, sofern noetig und moeglich */
	if ((SA_erw in (0,99)) and (SA_erwV not in (0,99))) then SA_erw=SA_erwV;

/*	SA_erw durch aussagekraeftigen Muttereintrag ergaenzen, sofern noch immer noetig 
	und moeglich */
	if ((SA_erw in (0,99)) and (SA_erwM not in (0,99))) then SA_erw=SA_erwM;
end;

/*	im Ausland geborene Migranten direkt ausgegeben */
else do; 
	if MIG=11 then Kennung=1;
	else if MIG=21 then Kennung=2;
	else if MIG=22 then Kennung=2;
	else if MIG=23 then Kennung=3;
	else if MIG=25 then Kennung=3;
	else if MIG=29 then Kennung=4;
	else if MIG=31 then Kennung=5;
	else if MIG=41 then Kennung=6;
end;

* Recodierung wie SUF MZ 2008;
if (MIG=0 | MIG=77) then MIG=0;
if (MIG=29)         then MIG=21;
label MIG = "[MIG] Migrationsstatus MZ 2008";

* MIGS: Vergroeberungen, Recodierungen SA_erw => MIGS wie SUF; 
MIGS = SA_erw;
if (MIG=0) then MIGS=0;
label MIGS = "[MIGS] Erweiterte Staatsangeh. zum Migrationsstatus MZ 2008 (MIG)";


/* STAATSANGEHOERIGKEITEN zum Migrationsstatus zeitreihenkompatibel (MIG) 
Deutsche Zuwanderer ohne Einbuergerung sowie in Deutschland geborene 
Deutsche mit ein-/beidseitigem Migrationshintergund => 0 (deutsch) */
	MIGS_R = MIGS;
	if MIG in (0,11,21,22,23,25,29,61,62,63,64,71,72,73,74) then MIGS_R = 0;
Label MIGS_R = "[MIGS_R] Erw. Staatsangeh. zum Mig-status 2008 zeitreihenkompatibel recodiert";


output mzjahr.BefragteTypisiert;
run;

/* 6. Umsetzung von Zeitreihenkompatibilitaet (nur MZ 2005 und 2009, entfaellt im MZ 2008) */


/* ********** ENDE MIG-TYPISIERUNG *************** */



/* 7. Variablendefinition fuer SUF- und Fachserien-Ergebnisse

   Fuer Vergleiche mit Tab. 2: Bevoelkerung nach detailliertem Migrationsstatus, Altersgruppen und Geschlecht.
   Statistisches Bundesamt (2010): Fachserie 1, Reihe 2.2, Bevoelkerung mit 
   Migrationshintergrund, Ergebnisse des Mikrozensus 2008. Wiesbaden. 
*/
proc format; 
value migstatus (multilabel notsorted) /* Lfd. Nr. in Tab. 2 */
   0-77                          = "Z001 Bevoelkerung insgesamt [0-77]"
   0,11,77                       = "Z002 Personen ohne Migrationshintergrund [0,11,77]"
   21-29,31,32,41-43,52-54,62-64 = "Z005 Personen mit Mig-hintergrund i.e.S. [21-64]"
   21-29,31,41                   = "Z034 Personen mit eigener Migrationserfahrung [21-31,41]"
   41                            = "Z062 + Auslaender [41]"
   21-29,31                      = "Z089 + Deutsche [21-31]"
   21-29                         = "Z090   - Spaetaussiedler [21-29]"
   31                            = "Z097   - durch Einbuergerung [31]"
   42,43,32,52-54,62-64          = "Z119 Personen ohne eigene Mig-erfahrung [32,42-64]"
   42,43                         = "Z126 + Auslaender [42,43]"
   32,52-54,62-64                = "Z133 + Deutsche [32,52-64]"
   32                            = "Z134   - durch Einbuergerung [32]"
   52-54,62-64                   = "Z140   - mit mind. 1 zugew. o. als Ausl. in D geb. Elternteil [52-64]"
   62-64                         = "Z141   # mit beidseitigem Mig-hintergrund [62-64]"
   52-54                         = "Z142   # mit einseitigem Mig-hintergrund [52-54]";
run;

proc format;
value staatsangeh (multilabel notsorted) /* Lfd. Nr. in Tab. 2 */
	0-99                        = "Z00 Insgesamt"
	01-39,56-59                 = "Z06 Europa"
	4,9,10,13,21-25,31-33,35,36 = "Z07 o EU 27"
	10                          = "Z08 o Griechenland"
	13                          = "Z09 o Italien"
	23                          = "Z10 o Polen"
	2,5,6,14,26,28,34,38,39,56-59	= "Z12 o Sonstiges Europa"
	2                           = "Z13 o Bosnien und Herzegowina"
	14                          = "Z14 o Kroatien"
	26                          = "Z15 o Russische Foederation"
	58,59                       = "Z16 o Serbien und Montenegro"
	34                          = "Z17 o Trkei"
	56                          = "Z18 o Ukraine"
	40-42                       = "Z19 Afrika"
	43-46                       = "Z20 Amerika"
	47-54,57                    = "Z22 Asien, Australien und Ozeanien"
	47,48,49,57                 = "Z23 o Naher und Mittlerer Osten"
	57                          = "Z24 Kasachstan"
	50-52                       = "Z25 o Sd- und Sdostasien"
	0,55,98	                    = "Z26 Ohne Angabe bzw. unzutreffend";
run;



/* Sortierung nach Ordnungsnummern fuer Zuspielen der erstellten 
   Variablen MIG und MIGS zum Scientific Use File */
proc sort data=mzjahr.BefragteTypisiert;
	by EF1 EF3 EF4 EF5b EF12 EF5a;
run;



/* Fallzahlen */
proc freq data=mzjahr.BefragteTypisiert;
     tables MIG MIGS /missing;
run;


/* TEST - Vergleich mit SUF */
proc freq data=mzjahr.BefragteTypisiert (where=(mig^=mig_o));
     tables MIG*MIG_O  /missing;
run;
* MIG=32 MIG_O=31: n=  78 --- OK, da Unterschied Jahresbestand/-berhang (in MIG_O im SUF) aufgehoben;
* MIG=42 MIG_O=43: n= 234 --- OK, da neue Konversionstabelle 'conversion';

proc freq data=mzjahr.BefragteTypisiert (where=(migs^=migs_o));
     tables MIGS*MIGS_O  /missing;
run;
* Keine Differenzen;



/* Vergleich mit Tab. 2, FS 1, R 2.2 
   hochgerechnet, Bevoelkerung am Hauptwohnort */
proc means data=mzjahr.BefragteTypisiert (keep=EF30 AHRFQ MIG) SUM; 
	where (EF30>=1 & ef30<=2); /* Bevoelkerung am Hauptwohnsitz */
	var  ahrfq;
	format MIG migstatus.;
	class MIG / mlf order=fmt; 
run;

/* Vergleich mit Tab. 2, FS 1, R 2.2 
hochgerechnet, Bevoelkerung am Hauptwohnort 
Personen mit Migrationshintergrund im engeren Sinn (mig=21-64) 
ZU BEACHTEN: Aufgrund fehlender differenzierter Angaben zur 2. Staatsangehoerigkeit 
             (EF370) koennen Abweichungen zur Fachserie auftreten */
proc means data=mzjahr.BefragteTypisiert (keep=EF30 AHRFQ MIG MIGS_R) SUM nonobs; 
	where (EF30>=1 & ef30<=2 & mig>=21 & mig<=64); /* Bevoelkerung am Hauptwohnsitz */
	var  ahrfq;
	format MIGS_R staatsangeh.;
	class MIGS_R / mlf order=fmt; 
run;
